"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const processMagicComments_1 = tslib_1.__importDefault(require("../scripts/createProject/processMagicComments"));
const log_1 = tslib_1.__importDefault(require("../utils/log"));
const themeUtilsConfigTemplate_1 = require("../utils/themeUtilsConfigTemplate");
const process = require('process');
const path = require('path');
const fs = require('fs');
const execa = require('execa');
exports.default = async (args) => {
    if (!args[0]) {
        console.error('Error: No output folder provided');
        process.exit(1);
    }
    const outputPathName = args[0].toLowerCase();
    const integrationThemePath = args[1];
    const configFileName = 'theme-utils.config.js';
    const configFilePath = path.join(process.cwd(), configFileName);
    const generatedTemplatePath = path.join(process.cwd(), outputPathName);
    if (fs.existsSync(configFilePath)) {
        fs.unlinkSync(configFilePath);
    }
    fs.appendFile(configFilePath, themeUtilsConfigTemplate_1.vsfTuConfig(outputPathName, integrationThemePath), async (err) => {
        if (err)
            throw err;
        try {
            await execa('vsf-tu');
            fs.unlinkSync(configFilePath);
            log_1.default.info('Updating Nuxt config');
            try {
                const nuxtConfigPath = path.join(generatedTemplatePath, 'nuxt.config.js');
                await processMagicComments_1.default(nuxtConfigPath);
            }
            catch (error) {
                log_1.default.error('No nuxt.config.js has been found in integration template');
                process.exit(1);
            }
            log_1.default.success('Template generated');
        }
        catch (error) {
            console.error(error);
            process.exit(1);
        }
    });
};
//# sourceMappingURL=generate-template.js.map