"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const getIntegrations_1 = tslib_1.__importDefault(require("../utils/getIntegrations"));
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const copyProject_1 = tslib_1.__importDefault(require("../scripts/copyProject"));
const path_1 = tslib_1.__importDefault(require("path"));
const createProject_1 = tslib_1.__importDefault(require("../scripts/createProject"));
exports.default = async (args) => {
    const CUSTOM_TEMPLATE = 'Custom template from Github';
    const cwd = process.cwd();
    const integrationTemplatesDirectory = path_1.default.resolve(__dirname, '../../templates');
    const integrations = getIntegrations_1.default();
    const integrationsNames = Object.keys(integrations);
    let projectName = args[0];
    if (!projectName) {
        const { typedProjectName } = await inquirer_1.default.prompt([
            {
                type: 'input',
                name: 'typedProjectName',
                message: 'What\'s your project name?',
                validate(value) {
                    if (value.trim().length > 0) {
                        return true;
                    }
                    return 'Please provide longer name';
                }
            }
        ]);
        projectName = typedProjectName;
    }
    const { chosenIntegration } = await inquirer_1.default.prompt([
        {
            type: 'list',
            name: 'chosenIntegration',
            message: 'Choose integration',
            choices: [...integrationsNames, CUSTOM_TEMPLATE]
        }
    ]);
    if (chosenIntegration !== CUSTOM_TEMPLATE) {
        await createProject_1.default({
            integration: chosenIntegration,
            targetPath: integrationTemplatesDirectory,
            repositoryLink: integrations[chosenIntegration]
        });
        return copyProject_1.default(chosenIntegration, path_1.default.resolve(cwd, projectName), projectName);
    }
    const { otherIntegrationName } = await inquirer_1.default.prompt([
        {
            type: 'input',
            name: 'otherIntegrationName',
            message: 'Provide integration name:',
            validate(value) {
                if (value.trim().length === 0) {
                    return 'Please provide longer name';
                }
                return true;
            }
        }
    ]);
    const { otherIntegrationGitLink } = await inquirer_1.default.prompt([
        {
            type: 'input',
            name: 'otherIntegrationGitLink',
            message: 'Provide integration repository git link via https:',
            validate(value) {
                /* eslint-disable-next-line no-useless-escape*/
                const gitLinkRegex = /https?:(\/\/)?(.*?)(\.git)(\/?|\#[-\d\w._]+?)$/;
                if (value.trim().length === 0 || !gitLinkRegex.test(value)) {
                    return 'Please provide git repository https link';
                }
                return true;
            }
        }
    ]);
    await createProject_1.default({
        integration: otherIntegrationName,
        targetPath: integrationTemplatesDirectory,
        repositoryLink: otherIntegrationGitLink
    });
    return copyProject_1.default(otherIntegrationName, path_1.default.resolve(cwd, projectName), projectName);
};
//# sourceMappingURL=init.js.map