"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const shell = require('shelljs');
const log_1 = tslib_1.__importDefault(require("../../utils/log"));
const processMagicComments_1 = tslib_1.__importDefault(require("./processMagicComments"));
const process = tslib_1.__importStar(require("process"));
const fs = tslib_1.__importStar(require("fs"));
const rimraf = require('rimraf');
async function createProject({ integration, targetPath, repositoryLink }) {
    const templatePath = path_1.default.join(targetPath, integration);
    if (fs.existsSync(templatePath)) {
        try {
            rimraf.sync(templatePath);
        }
        catch (e) {
            log_1.default.error('Unable to remove old template');
            return;
        }
    }
    try {
        await shell.exec(`git clone ${repositoryLink} ${templatePath}`);
    }
    catch (error) {
        log_1.default.error('Unable to get integration template from git repository');
        return;
    }
    log_1.default.info('Updating Nuxt config');
    try {
        const absoluteTargetPath = path_1.default.isAbsolute(templatePath)
            ? templatePath
            : path_1.default.join(__dirname, templatePath);
        const nuxtConfigPath = path_1.default.join(absoluteTargetPath, 'nuxt.config.js');
        await processMagicComments_1.default(nuxtConfigPath);
    }
    catch (error) {
        log_1.default.error('No nuxt.config.js has been found in integration template');
        process.exit(1);
    }
}
exports.default = createProject;
//# sourceMappingURL=index.js.map